﻿using System;
using UnityEngine;
using UnityEngine.UI;

namespace everlaster
{
    static class MVRScriptExtensions
    {
        public static string GetPackageId(this MVRScript script)
        {
            string id = script.name.Substring(0, script.name.IndexOf('_'));
            string filename = script.manager.GetJSON()["plugins"][id].Value;
            return ParsePackageIdFromPath(filename);
        }

        static string ParsePackageIdFromPath(string path)
        {
            if(string.IsNullOrEmpty(path))
            {
                return null;
            }

            int idx = path.IndexOf(":/", StringComparison.Ordinal);
            return idx >= 0 ? path.Substring(0, idx) : null;
        }

        public static Transform InstantiateTextField(this MVRScript script, Transform parent = null) =>
            Instantiate(script.manager.configurableTextFieldPrefab, parent);

        public static Transform InstantiateButton(this MVRScript script, Transform parent = null) =>
            Instantiate(script.manager.configurableButtonPrefab, parent);

        public static Transform InstantiateSlider(this MVRScript script, Transform parent = null) =>
            Instantiate(script.manager.configurableSliderPrefab, parent);

        public static Transform InstantiateToggle(this MVRScript script, Transform parent = null) =>
            Instantiate(script.manager.configurableTogglePrefab, parent);

        public static Transform InstantiatePopup(this MVRScript script, Transform parent = null) =>
            Instantiate(script.manager.configurablePopupPrefab, parent);

        public static Transform InstantiateScrollablePopup(this MVRScript script, Transform parent = null) =>
            Instantiate(script.manager.configurableScrollablePopupPrefab, parent);

        public static Transform InstantiateFilterablePopup(this MVRScript script, Transform parent = null) =>
            Instantiate(script.manager.configurableFilterablePopupPrefab, parent);

        static Transform Instantiate(Transform prefab, Transform parent = null)
        {
            var transform = UnityEngine.Object.Instantiate(prefab, parent, false);
            UnityEngine.Object.Destroy(transform.GetComponent<LayoutElement>());
            return transform;
        }
    }
}
